%This script will find the targeted data and store it all together
function [concentration] = Process(currentFile, previousFile0, previousFile1, previousFile2, baseFile)

% acquisition constants (from epocd.c)
headsetFrequency = 128;
averageFile = sprintf('%s_averages.csv', baseFile);
referenceFile = sprintf('%s_references.csv', baseFile);

% EEG data
% beta waves correlate to concentration; frontal, symmetric
beta_min = 12;
beta_max = 30;

% 1. Grab data from file
% 2. Bandpass data for beta waves
% 3. Find the referenced average power of each channel & determine if concentrating
% 4. Write data to file
% 5. Determine if concentrating

% 1]
% data acquired from input file
[GYROXdata GYROYdata F3data F4data F7data F8data FC5data FC6data AF3data AF4data O1data O2data P7data P8data T7data T8data] = splitData(currentFile,previousFile0, previousFile1, previousFile2);
    
% 2]
[GYROXband GYROYband F3band F4band F7band F8band FC5band FC6band AF3band AF4band O1band O2band P7band P8band T7band T8band] = bandpassData(headsetFrequency, beta_min, beta_max,GYROXdata, GYROYdata, F3data, F4data, F7data, F8data, FC5data, FC6data, AF3data, AF4data, O1data, O2data, P7data, P8data, T7data, T8data);
         
% 3]
[GYROX GYROY F3 F4 F7 F8 FC5 FC6 AF3 AF4 O1 O2 P7 P8 T7 T8 concentration] = ReferencedAverage(referenceFile,GYROXband, GYROYband, F3band, F4band, F7band, F8band, FC5band, FC6band, AF3band, AF4band, O1band, O2band, P7band, P8band, T7band, T8band);

% 4]
writer = fopen(averageFile, 'a');
fprintf(writer, '%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f\n', GYROX, GYROY, F3, F4, F7, F8, FC5, FC6, AF3, AF4, O1, O2, P7, P8, T7, T8);
fclose(writer);



end
