/* Emotic EPOC daemon that decrypt stream using ECB and RIJNDAEL-128 cipher
 * (well, not yet a daemon...)
 * 
 * Usage: epocd (consumer/research) /dev/emotiv/encrypted output_file
 * 
 * Make sure to pick the right type of device, as this determines the key
 * */

#include <stdio.h>
#include <string.h>
#include "libepoc.h"

#define headsetFrequency 128	// 2^7 Hertz 
#define acquisitionTime .25	// (2^2)^-1 seconds

// gathers data for appropriate amount of time, writes to file
void Acquire(char* filename, struct epoc_frame frame, epoc_device* d, char* data)
{
	// headset data
	FILE *input;
	FILE *output;
	
	// remove any existing file with name [filename] to avoid append errors
	remove(filename);

	// gather appropriate size of data
	int i;
	for(i = 0; i < (headsetFrequency * acquisitionTime); i++)
	{
		if(epoc_read_data(d, data) > 0)
		{
			fflush(stdout);

			epoc_get_next_frame(&frame, data);

			// write out headset data in columns
			output = fopen(filename, "a+");
			fprintf(output,"%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d\n",
				frame.gyroX, frame.gyroY,
				frame.F3, frame.F4, frame.F7, frame.F8,
				frame.FC5, frame.FC6,
				frame.AF3, frame.AF4,
				frame.O1, frame.O2,
				frame.P7, frame.P8,
				frame.T7, frame.T8);
	
			fclose(output);
		}
	}
}

int main(int argc, char **argv)
{
	// constants
	const int acquisitionSamples = 100;

	char* filename;
	filename = argv[1];

	enum headset_type type;
  
	char raw_frame[32];
	struct epoc_frame frame;
	epoc_device* d;
	char data[32];
	
  	// initialize headset
	d = epoc_create();

	// check for headset connected
	printf("Current epoc devices connected: %d\n", epoc_get_count(d, EPOC_VID, EPOC_PID));
	if(epoc_open(d, EPOC_VID, EPOC_PID, 0) != 0)
	{
		printf("CANNOT CONNECT\n");
		return 1;
	}

	Acquire(filename, frame, d, data);

	// remove headset data
	epoc_close(d);
	epoc_delete(d);
	return 0;
}

