#include <stdio.h>   // standard input / output functions
#include <stdlib.h>  // general standard library functions
#include <unistd.h>  // UNIX standard function definitions
#include <fcntl.h>   // File control definitions
#include <termios.h> // POSIX terminal control definitions
#include <string.h>


int open_port(int device);
int configure_port(int fd);
int read_lines(int fd, char* buf, int lines);

int main(int argc, char* argv[])
{
   // usbtty0
   int fd0 = open_port(0);
   fd0 = configure_port(fd0);

   // usbtty1
   int fd1 = open_port(1);
   fd1 = configure_port(fd1);

   int position;
   char* input;
   input = argv[1];

   char buffer[255];
   char command[32];
   sprintf(command, "%s", input);
   //printf("sending %s\n", command);

   // signals to ttyusb0
   ///////////////////////////////////////////////////////////////
   write(fd0, command,strlen(command));
   position = read_lines(fd0, buffer, 255); // get next 3 lines

   if (0 >= position)
   {
      printf("\nPort closed unexpectedly after %d characters, exiting.\n",
             -position);
      exit(-1);
   }
   else
   {
	//printf("GOT: %s\n", buffer);
   }
   close(fd0);
   /////////////////////////////////////////////////


   // signals to ttyusb1
   ////////////////////////////////////////////////////////////
   write(fd1, command,strlen(command));
   position = read_lines(fd1, buffer, 255); // get next 3 lines

   if (0 >= position)
   {
      printf("\nPort closed unexpectedly after %d characters, exiting.\n",
             -position);
      exit(-1);
   }
   else
   {
	//printf("GOT: %s\n", buffer);
   }
   close(fd1);
   //////////////////////////////////////////////////////////////////

   return 0;
}

/* read a set number of lines of text from the port */
int read_lines(int fd, char* buf, int lines)
{
   int count;
   int line, row = 0;

   for (line = 0; lines < lines; line++)
   {
      for (; buf[row] != '\n'; row++)
      {
         if (0 >= read(fd, (buf + row), 1))  // port closed for some reason
            return -count;
         else
         {
            putchar(buf[row]);
            count++;
         }
      }
   }
   return count;
}

/*Function to open a serial port*/
int open_port(int device)
{
   int fd; // file description for the serial port

   //fd = open("/dev/ttyUSB0", O_RDWR | O_NOCTTY | O_NONBLOCK);
   if(device == 0)
   {
	fd = open("/dev/ttyUSB0", O_RDWR | O_NOCTTY | O_NDELAY);
   }
   else
   {
	fd = open("/dev/ttyUSB1", O_RDWR | O_NOCTTY | O_NDELAY);
   }
   

   if(fd == -1) // if open is unsucessful
   {
      perror("open_port: Unable to open /dev/ttyS0 - ");
   }
   else
   {
      //fcntl(fd, F_SETFL, O_NONBLOCK);
      fcntl(fd, F_SETFL, 0);
   }

   return(fd);
}

/*Port configuration - constant BAUD rate B57600*/
int configure_port(int fd)
{
   struct termios port_settings;      // structure to store the port settings in

   tcgetattr(fd, &port_settings);
   cfsetispeed(&port_settings, B57600);    // set baud rates
   cfsetospeed(&port_settings, B57600);

   port_settings.c_cflag |= (CLOCAL | CREAD);

   port_settings.c_cflag &= ~PARENB;    // set no parity, stop bits, data bits
   port_settings.c_cflag &= ~CSTOPB;
   port_settings.c_cflag &= ~CSIZE;
   port_settings.c_cflag |= CS8;
   
   //options.c_cflag &= ~CRTSCTS;  // disable hardware flow control
   //port_settings.c_lflag |= (ICANON | ECHO | ECHOE);
   port_settings.c_lflag &= ~(ICANON | ECHO | ECHOE | ISIG);

   tcsetattr(fd, TCSANOW, &port_settings);    // apply the settings to the port

   return(fd);
}
